@@ -16,9 +16,10 @@ class EntryBar(Frame):
         if picks is None:
             picks = []
         self.vars = []
+        w = min(max(map(lambda x: len(x), picks)), 15)
         for pick in picks:
             row = Frame(parent)
-            label = Label(row, width=10, text=pick, anchor=anchor)
+            label = Label(row, width=w, text=pick, anchor=anchor)
             entry = Entry(row)
             row.pack(side=TOP, fill=X, padx=1, pady=1)
             label.pack(side=side)
